﻿using System;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using Telerik.Windows.Controls;
using System.Collections.Generic;
using Telerik.Windows.Controls.RibbonBar;
using RadRibbonBarPrism.Common;
using System.Windows.Data;
using Microsoft.Practices.Prism.Regions;

namespace RadRibbonBarPrism.Adapters
{
    internal static class RibbonAdapterHelper
    {
        public static void RemoveModuleDefinition(ModuleDefinition module, RadRibbonBar regionTarget)
        {
            RadRibbonTab moduleTab = regionTarget.Items.Cast<RadRibbonTab>().Single(o => o.Name == module.ModuleName);
            regionTarget.Items.Remove(moduleTab);
        }

        public static void AddModuleDefinition(ModuleDefinition module, RadRibbonBar regionTarget)
        {
            RadRibbonTab tab = new RadRibbonTab();
            tab.DataContext = module;
            tab.SetBinding(RadRibbonTab.HeaderProperty,new Binding("ModuleName"));

            if (!string.IsNullOrEmpty(module.RegionName))
            {
                RegionManager.SetRegionName(tab, module.RegionName);
            }

            foreach (GroupDefinition groupDefinition in module.GroupDefinitions)
            {
                AddGroupDefinition(groupDefinition, tab);
            }

            regionTarget.Items.Add(tab);
        }



        public static void RemoveGroupDefinition(GroupDefinition groupDefinition, RadRibbonTab regionTarget)
        {
            RadRibbonGroup group = regionTarget.Items.Cast<RadRibbonGroup>().Single(o => o.Name == groupDefinition.GroupName);
            regionTarget.Items.Remove(group);
        }

        public static void AddGroupDefinition(GroupDefinition groupDefinition, RadRibbonTab regionTarget)
        {
            RadRibbonGroup group = new RadRibbonGroup();
            group.DataContext = groupDefinition;
            group.SetBinding(RadRibbonTab.HeaderProperty, new Binding("GroupName"));

            foreach (ActionDefinition actionDefinition in groupDefinition.ActionDefinitions)
            {
                if (actionDefinition.SubActions.Count <= 0)
                {
                    RadRibbonButton button = new RadRibbonButton();
                    button.DataContext = actionDefinition;
                    button.SetBinding(RadRibbonButton.TextProperty, new Binding("Name"));
                    button.SetBinding(RadRibbonButton.LargeImageProperty, new Binding("Image"));
                    button.Command = actionDefinition.Command;
                    button.Size = ButtonSize.Large;
                    group.Items.Add(button);
                }
                else
                {
                    RadRibbonSplitButton button = new RadRibbonSplitButton();
                    button.DataContext = actionDefinition;
                    button.SetBinding(RadRibbonSplitButton.TextProperty, new Binding("Name"));
                    button.SetBinding(RadRibbonSplitButton.LargeImageProperty, new Binding("Image"));
                    button.Command = actionDefinition.Command;
                    button.Size = ButtonSize.Large;

                    RadContextMenu contextMenu = new RadContextMenu();
                    button.DropDownContent = contextMenu;

                    LoadSubActions(contextMenu.Items, actionDefinition.SubActions);

                    group.Items.Add(button);
                }
            }

            regionTarget.Items.Add(group);
        }

        private static void LoadSubActions(ItemCollection itemCollection, IEnumerable<ActionDefinition> actions)
        {
            foreach (var subAction in actions)
            {
                RadMenuItem subItem = new RadMenuItem();

                subItem.Header = subAction.Name;
                subItem.Command = subAction.Command;
                subItem.Icon = subAction.Image;

                LoadSubActions(subItem.Items, subAction.SubActions);

                itemCollection.Add(subItem);
            }
        }
    }
}
